pub fn detect() -> AuthSummaryExpand description
Detect the active auth strategy from the current process environment. Cheap; no subprocess, no filesystem reads.
pub fn detect() -> AuthSummaryDetect the active auth strategy from the current process environment. Cheap; no subprocess, no filesystem reads.