RawCommand

Struct RawCommand 

pub struct RawCommand { /* private fields */ }
Escape hatch for running arbitrary claude subcommands not yet covered by dedicated command builders.

Example

use claude_wrapper::{Claude, ClaudeCommand, RawCommand};

let claude = Claude::builder().build()?;

let output = RawCommand::new("agents")
    .arg("--setting-sources")
    .arg("user,project")
    .execute(&claude)
    .await?;

println!("{}", output.stdout);

Implementations

Source

impl RawCommand

pub fn new(subcommand: impl Into<String>) -> Self

Create a new raw command with the given subcommand.

pub fn arg(self, arg: impl Into<String>) -> Self

Add a single argument.

pub fn args(self, args: impl IntoIterator<Item = impl Into<String>>) -> Self

Add multiple arguments.