pub struct TempMcpConfig { /* private fields */ }Expand description
A temporary MCP config file that is cleaned up when dropped.
Created by McpConfigBuilder::build_temp(). Use path()
to get the file path for passing to QueryCommand::mcp_config().
Implementations