run_claude

Function run_claude 

pub async fn run_claude(
    claude: &Claude,
    args: Vec<String>,
) -> Result<CommandOutput>
Run a claude command with the given arguments.

If the Claude client has a retry policy set, transient errors will be retried according to that policy. A per-command retry policy can be passed to override the client default.